prettyqt.syntaxhighlighters package
===================================

Submodules
----------

prettyqt.syntaxhighlighters.jsonhighlighter module
--------------------------------------------------

.. automodule:: prettyqt.syntaxhighlighters.jsonhighlighter
    :members:
    :undoc-members:
    :show-inheritance:

prettyqt.syntaxhighlighters.pythonhighlighter module
----------------------------------------------------

.. automodule:: prettyqt.syntaxhighlighters.pythonhighlighter
    :members:
    :undoc-members:
    :show-inheritance:

prettyqt.syntaxhighlighters.yamlhighlighter module
--------------------------------------------------

.. automodule:: prettyqt.syntaxhighlighters.yamlhighlighter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: prettyqt.syntaxhighlighters
    :members:
    :undoc-members:
    :show-inheritance:
